@@ -29,6 +29,8 @@ import (
 	"github.com/rs/zerolog/log"
 	vfs "github.com/twpayne/go-vfs/v4"
 	"go.uber.org/multierr"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
 // An ExternalType is a type of external source.
@@ -82,6 +84,7 @@ type SourceState struct {
 	version                 semver.Version
 	mode                    Mode
 	defaultTemplateDataFunc func() map[string]interface{}
+	controlOnly             bool
 	readTemplateData        bool
 	userTemplateData        map[string]interface{}
 	priorityTemplateData    map[string]interface{}
@@ -109,6 +112,13 @@ func WithCacheDir(cacheDirAbsPath AbsPath) SourceStateOption {
 	}
 }
 
+// WithControlOnly sets whether only control plane information should be read.
+func WithControlOnly(controlOnly bool) SourceStateOption {
+	return func(s *SourceState) {
+		s.controlOnly = controlOnly
+	}
+}
+
 // WithDestDir sets the destination directory.
 func WithDestDir(destDirAbsPath AbsPath) SourceStateOption {
 	return func(s *SourceState) {
@@ -744,12 +754,12 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		parentSourceRelPath, sourceName := sourceRelPath.Split()
 
 		switch {
-		case strings.HasPrefix(fileInfo.Name(), dataName):
+		case isPrefixDotFormat(fileInfo.Name(), dataName):
 			if !s.readTemplateData {
 				return nil
 			}
 			return s.addTemplateData(sourceAbsPath)
-		case strings.HasPrefix(fileInfo.Name(), externalName):
+		case isPrefixDotFormat(fileInfo.Name(), externalName):
 			return s.addExternal(sourceAbsPath)
 		case fileInfo.Name() == ignoreName:
 			return s.addPatterns(s.ignore, sourceAbsPath, parentSourceRelPath)
@@ -802,6 +812,8 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				return vfs.SkipDir
 			}
 			return nil
+		case s.controlOnly:
+			return nil
 		case fileInfo.IsDir():
 			da := parseDirAttr(sourceName.String())
 			targetRelPath := parentSourceRelPath.Dir().TargetRelPath(s.encryption.EncryptedSuffix()).JoinString(da.TargetName)
@@ -832,6 +844,10 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		return err
 	}
 
+	if s.controlOnly {
+		return nil
+	}
+
 	// Read externals.
 	externalRelPaths := make(RelPaths, 0, len(s.externals))
 	for externalRelPath := range s.externals {
@@ -1075,6 +1091,9 @@ func (s *SourceState) addTemplateData(sourceAbsPath AbsPath) error {
 // addTemplatesDir adds all templates in templatesDirAbsPath to s.
 func (s *SourceState) addTemplatesDir(templatesDirAbsPath AbsPath) error {
 	walkFunc := func(templateAbsPath AbsPath, fileInfo fs.FileInfo, err error) error {
+		if err == nil && fileInfo.Mode().Type() == fs.ModeSymlink {
+			fileInfo, err = s.system.Stat(templateAbsPath)
+		}
 		switch {
 		case err != nil:
 			return err
@@ -1147,20 +1166,7 @@ func (s *SourceState) getExternalDataRaw(
 	if err != nil {
 		return nil, err
 	}
-	resp, err := s.httpClient.Do(req)
-	if resp != nil {
-		s.logger.Err(err).
-			Str("method", req.Method).
-			Int("statusCode", resp.StatusCode).
-			Str("status", resp.Status).
-			Stringer("url", req.URL).
-			Msg("HTTP")
-	} else {
-		s.logger.Err(err).
-			Str("method", req.Method).
-			Stringer("url", req.URL).
-			Msg("HTTP")
-	}
+	resp, err := chezmoilog.LogHTTPRequest(s.logger, s.httpClient, req)
 	if err != nil {
 		return nil, err
 	}
@@ -1887,7 +1893,8 @@ func (s *SourceState) readVersionFile(sourceAbsPath AbsPath) error {
 	if err != nil {
 		return err
 	}
-	if s.version.LessThan(*version) {
+	var zeroVersion semver.Version
+	if s.version != zeroVersion && s.version.LessThan(*version) {
 		return &TooOldError{
 			Have: s.version,
 			Need: *version,
