@@ -930,6 +930,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 		"chezmoi": map[string]interface{}{
 			"arch":         runtime.GOARCH,
 			"args":         os.Args,
+			"cacheDir":     c.CacheDirAbsPath.String(),
 			"configFile":   c.configFileAbsPath.String(),
 			"executable":   executable,
 			"fqdnHostname": fqdnHostname,
@@ -1245,6 +1246,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 
 	persistentFlags := rootCmd.PersistentFlags()
 
+	persistentFlags.Var(&c.CacheDirAbsPath, "cache", "Set cache directory")
 	persistentFlags.Var(&c.Color, "color", "Colorize output")
 	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "Set destination directory")
 	persistentFlags.Var(&c.Mode, "mode", "Mode")
@@ -1256,6 +1258,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.BoolVarP(&c.Verbose, "verbose", "v", c.Verbose, "Make output more verbose")
 	persistentFlags.VarP(&c.WorkingTreeAbsPath, "working-tree", "W", "Set working tree directory")
 	for viperKey, key := range map[string]string{
+		"cacheDir":        "cache",
 		"color":           "color",
 		"destDir":         "destination",
 		"persistentState": "persistent-state",
@@ -1533,7 +1536,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	// Log basic information.
 	c.logger.Info().
 		Object("version", c.versionInfo).
-		Strs("args", args).
+		Strs("args", os.Args).
 		Str("goVersion", runtime.Version()).
 		Msg("persistentPreRunRootE")
 
@@ -1939,6 +1942,34 @@ func (c *Config) targetRelPathsBySourcePath(
 	return targetRelPaths, nil
 }
 
+// targetValidArgs returns completions for targets.
+func (c *Config) targetValidArgs(
+	cmd *cobra.Command, args []string, toComplete string,
+) ([]string, cobra.ShellCompDirective) {
+	toCompleteAbsPath, err := chezmoi.NewAbsPathFromExtPath(toComplete, c.homeDirAbsPath)
+	if err != nil {
+		cobra.CompErrorln(err.Error())
+		return nil, cobra.ShellCompDirectiveError
+	}
+	sourceState, err := c.newSourceState(cmd.Context())
+	if err != nil {
+		cobra.CompErrorln(err.Error())
+		return nil, cobra.ShellCompDirectiveError
+	}
+	var completions []string
+	if err := sourceState.ForEach(func(targetRelPath chezmoi.RelPath, sourceStateEntry chezmoi.SourceStateEntry) error {
+		completion := c.DestDirAbsPath.Join(targetRelPath).String()
+		if strings.HasPrefix(completion, toCompleteAbsPath.String()) {
+			completions = append(completions, completion)
+		}
+		return nil
+	}); err != nil {
+		cobra.CompErrorln(err.Error())
+		return nil, cobra.ShellCompDirectiveError
+	}
+	return completions, cobra.ShellCompDirectiveNoFileComp
+}
+
 // tempDir returns the temporary directory for the given key, creating it if
 // needed.
 func (c *Config) tempDir(key string) (chezmoi.AbsPath, error) {
